﻿namespace Eq3.misc.usb_bat
{
    using System;
    using System.Collections.Generic;
    using System.Text;
    using System.Threading;
    using System.Windows;
    using UsbLibrary;

    public class UsbBatDevice
    {
        private UsbHidPort usb;

        public UsbBatDevice()
        {
            this.usb = new UsbHidPort();
            this.usb.VendorId = 0x18EF; // VendorID von ELV z.B. aus Windows Gerätemanager zu entnehmen
            this.usb.ProductId = 0xE01A; // ProductID des USB-BAT z.B. aus Windows Gerätemanager zu entnehmen
            this.usb.OnSpecifiedDeviceArrived += new EventHandler(this.OnSpecifiedDeviceArrived);
            
            // Prüfen ob Gerät angeschlossen
            this.usb.CheckDevicePresent();
        }

        public event DataRecievedEventHandler ReportReceived;

        public event EventHandler DeviceDisconnected;

        public bool DeviceConnected
        {
            get
            {
                return this.usb.SpecifiedDevice != null;
            }
        }

        public void WriteData(byte[] data)
        {
            this.WriteToDevice(data);
        }

        private void OnSpecifiedDeviceArrived(object sender, EventArgs e)
        {
            this.usb.SpecifiedDevice.DataRecieved += new DataRecievedEventHandler(this.SpecifiedDevice_DataRecieved);
            this.usb.SpecifiedDevice.OnDeviceRemoved += new EventHandler(this.SpecifiedDevice_OnDeviceRemoved);
        }

        private void SpecifiedDevice_DataRecieved(object sender, DataRecievedEventArgs args)
        {
            // Event weitergeben z.B. für das Hauptfenster
            if (this.ReportReceived != null)
            {
                this.ReportReceived(this, args);
            }
        }

        private void SpecifiedDevice_OnDeviceRemoved(object sender, EventArgs e)
        {
            // Prüfen ob Gerät angeschlossen
            this.usb.CheckDevicePresent();

            // Event weitergeben z.B. für das Hauptfenster
            if (this.DeviceDisconnected != null)
            {
                this.DeviceDisconnected(this, e);
            }
        }

        private void WriteToDevice(byte[] outputReportBuffer)
        {
            // Verbindung vor dem Senden prüfen, ggf. versuchen diese aufzubauen
            if (!this.DeviceConnected)
            {
                this.usb.CheckDevicePresent();
            }

            try
            {
                if (this.usb.SpecifiedDevice != null)
                {
                    this.usb.SpecifiedDevice.SendData(outputReportBuffer);
                }
                else
                {
                    MessageBox.Show("Es wurde kein Gerät gefunden.\r\nÜberprüfen Sie die Verbindung zum Gerät.");
                }
            }
            catch (Exception ex)
            {
                MessageBox.Show("Fehler in Kommunikation mit dem Gerät\r\n" + ex.Message);
            }
        }
    }
}
